/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSException;

import tango.stdc.stdarg : va_list;

import dwt.internal.cocoa.id;
import dwt.internal.cocoa.NSArray;
import dwt.internal.cocoa.NSDictionary;
import dwt.internal.cocoa.NSObject;
import dwt.internal.cocoa.NSString;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

public class NSException : NSObject
{

    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public NSArray callStackReturnAddresses ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_callStackReturnAddresses);
        return result !is null ? new NSArray(result) : null;
    }

    public static NSException exceptionWithName (NSString name, NSString reason, NSDictionary userInfo)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSException, OS.sel_exceptionWithName_1reason_1userInfo_1, name !is null ? name.id_ : null,
                reason !is null ? reason.id_ : null, userInfo !is null ? userInfo.id_ : null);
        return result !is null ? new NSException(result) : null;
    }

    public id initWithName (NSString aName, NSString aReason, NSDictionary aUserInfo)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_initWithName_1reason_1userInfo_1, aName !is null ? aName.id_ : null,
                aReason !is null ? aReason.id_ : null, aUserInfo !is null ? aUserInfo.id_ : null);
        return result !is null ? new id(result) : null;
    }

    public NSString name ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_name);
        return result !is null ? new NSString(result) : null;
    }

    public void raise ()
    {
        OS.objc_msgSend(this.id_, OS.sel_raise);
    }

    public static void static_raise_format_ (NSString name, NSString format)
    {
        OS.objc_msgSend(OS.class_NSException, OS.sel_raise_1format_1, name !is null ? name.id_ : null, format !is null ? format.id_ : null);
    }

    public static void static_raise_format_arguments_ (NSString name, NSString format, va_list argList)
    {
        OS.objc_msgSend(OS.class_NSException, OS.sel_raise_1format_1arguments_1, name !is null ? name.id_ : null, format !is null ? format.id_ : null,
                argList);
    }

    public NSString reason ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_reason);
        return result !is null ? new NSString(result) : null;
    }

    public NSDictionary userInfo ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_userInfo);
        return result !is null ? new NSDictionary(result) : null;
    }

}
