/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSFontDescriptor;

import dwt.internal.cocoa.CGFloat;
import dwt.internal.cocoa.id;
import dwt.internal.cocoa.NSAffineTransform;
import dwt.internal.cocoa.NSArray;
import dwt.internal.cocoa.NSDictionary;
import dwt.internal.cocoa.NSObject;
import dwt.internal.cocoa.NSSet;
import dwt.internal.cocoa.NSString;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

alias uint NSFontSymbolicTraits; 

public class NSFontDescriptor : NSObject
{

    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public NSDictionary fontAttributes ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_fontAttributes);
        return result !is null ? new NSDictionary(result) : null;
    }

    public NSFontDescriptor fontDescriptorByAddingAttributes (NSDictionary attributes)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_fontDescriptorByAddingAttributes_1, attributes !is null ? attributes.id_ : null);
        return result is this.id_ ? this : (result !is null ? new NSFontDescriptor(result) : null);
    }

    public NSFontDescriptor fontDescriptorWithFace (NSString newFace)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_fontDescriptorWithFace_1, newFace !is null ? newFace.id_ : null);
        return result is this.id_ ? this : (result !is null ? new NSFontDescriptor(result) : null);
    }

    public NSFontDescriptor fontDescriptorWithFamily (NSString newFamily)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_fontDescriptorWithFamily_1, newFamily !is null ? newFamily.id_ : null);
        return result is this.id_ ? this : (result !is null ? new NSFontDescriptor(result) : null);
    }

    public static NSFontDescriptor fontDescriptorWithFontAttributes (NSDictionary attributes)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSFontDescriptor, OS.sel_fontDescriptorWithFontAttributes_1,
                attributes !is null ? attributes.id_ : null);
        return result !is null ? new NSFontDescriptor(result) : null;
    }

    public NSFontDescriptor fontDescriptorWithMatrix (NSAffineTransform matrix)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_fontDescriptorWithMatrix_1, matrix !is null ? matrix.id_ : null);
        return result is this.id_ ? this : (result !is null ? new NSFontDescriptor(result) : null);
    }

    public static NSFontDescriptor static_fontDescriptorWithName_matrix_ (NSString fontName, NSAffineTransform matrix)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSFontDescriptor, OS.sel_fontDescriptorWithName_1matrix_1, fontName !is null ? fontName.id_ : null,
                matrix !is null ? matrix.id_ : null);
        return result !is null ? new NSFontDescriptor(result) : null;
    }

    public static NSFontDescriptor static_fontDescriptorWithName_size_ (NSString fontName, CGFloat size)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSFontDescriptor, OS.sel_fontDescriptorWithName_1size_1, fontName !is null ? fontName.id_ : null,
                size);
        return result !is null ? new NSFontDescriptor(result) : null;
    }

    public NSFontDescriptor fontDescriptorWithSize (CGFloat newPointSize)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_fontDescriptorWithSize_1, newPointSize);
        return result is this.id_ ? this : (result !is null ? new NSFontDescriptor(result) : null);
    }

    public NSFontDescriptor fontDescriptorWithSymbolicTraits (NSFontSymbolicTraits symbolicTraits)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_fontDescriptorWithSymbolicTraits_1, symbolicTraits);
        return result is this.id_ ? this : (result !is null ? new NSFontDescriptor(result) : null);
    }

    public id initWithFontAttributes (NSDictionary attributes)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_initWithFontAttributes_1, attributes !is null ? attributes.id_ : null);
        return result !is null ? new id(result) : null;
    }

    public NSFontDescriptor matchingFontDescriptorWithMandatoryKeys (NSSet mandatoryKeys)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_matchingFontDescriptorWithMandatoryKeys_1, mandatoryKeys !is null ? mandatoryKeys.id_ : null);
        return result is this.id_ ? this : (result !is null ? new NSFontDescriptor(result) : null);
    }

    public NSArray matchingFontDescriptorsWithMandatoryKeys (NSSet mandatoryKeys)
    {
        objc.id
                result = OS.objc_msgSend(this.id_, OS.sel_matchingFontDescriptorsWithMandatoryKeys_1, mandatoryKeys !is null ? mandatoryKeys.id_ : null);
        return result !is null ? new NSArray(result) : null;
    }

    public NSAffineTransform matrix ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_matrix);
        return result !is null ? new NSAffineTransform(result) : null;
    }

    public id objectForKey (NSString anAttribute)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_objectForKey_1, anAttribute !is null ? anAttribute.id_ : null);
        return result !is null ? new id(result) : null;
    }

    public CGFloat pointSize ()
    {
        return cast(CGFloat) OS.objc_msgSend_fpret(this.id_, OS.sel_pointSize);
    }

    public NSString postscriptName ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_postscriptName);
        return result !is null ? new NSString(result) : null;
    }

    public NSFontSymbolicTraits symbolicTraits ()
    {
        return cast(NSFontSymbolicTraits) OS.objc_msgSend(this.id_, OS.sel_symbolicTraits);
    }

}
