/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSHost;

import dwt.internal.cocoa.NSArray;
import dwt.internal.cocoa.NSObject;
import dwt.internal.cocoa.NSString;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

public class NSHost : NSObject
{

    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public NSString address ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_address);
        return result !is null ? new NSString(result) : null;
    }

    public NSArray addresses ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_addresses);
        return result !is null ? new NSArray(result) : null;
    }

    public static NSHost currentHost ()
    {
        objc.id result = OS.objc_msgSend(OS.class_NSHost, OS.sel_currentHost);
        return result !is null ? new NSHost(result) : null;
    }

    public static void flushHostCache ()
    {
        OS.objc_msgSend(OS.class_NSHost, OS.sel_flushHostCache);
    }

    public static NSHost hostWithAddress (NSString address)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSHost, OS.sel_hostWithAddress_1, address !is null ? address.id_ : null);
        return result !is null ? new NSHost(result) : null;
    }

    public static NSHost hostWithName (NSString name)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSHost, OS.sel_hostWithName_1, name !is null ? name.id_ : null);
        return result !is null ? new NSHost(result) : null;
    }

    public bool isEqualToHost (NSHost aHost)
    {
        return OS.objc_msgSend(this.id_, OS.sel_isEqualToHost_1, aHost !is null ? aHost.id_ : null) !is null;
    }

    public static bool isHostCacheEnabled ()
    {
        return OS.objc_msgSend(OS.class_NSHost, OS.sel_isHostCacheEnabled) !is null;
    }

    public NSString name ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_name);
        return result !is null ? new NSString(result) : null;
    }

    public NSArray names ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_names);
        return result !is null ? new NSArray(result) : null;
    }

    public static void setHostCacheEnabled (bool flag)
    {
        OS.objc_msgSend(OS.class_NSHost, OS.sel_setHostCacheEnabled_1, flag);
    }

}
