/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSMutableSet;

import dwt.internal.cocoa.id;
import dwt.internal.cocoa.NSArray;
import dwt.internal.cocoa.NSInteger;
import dwt.internal.cocoa.NSPredicate;
import dwt.internal.cocoa.NSSet;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

public class NSMutableSet : NSSet
{

    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public void addObject (id object)
    {
        OS.objc_msgSend(this.id_, OS.sel_addObject_1, object !is null ? object.id_ : null);
    }

    public void addObjectsFromArray (NSArray array)
    {
        OS.objc_msgSend(this.id_, OS.sel_addObjectsFromArray_1, array !is null ? array.id_ : null);
    }

    public void filterUsingPredicate (NSPredicate predicate)
    {
        OS.objc_msgSend(this.id_, OS.sel_filterUsingPredicate_1, predicate !is null ? predicate.id_ : null);
    }

    public NSMutableSet initWithCapacity (NSUInteger numItems)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_initWithCapacity_1, numItems);
        return result !is null ? this : null;
    }

    public void intersectSet (NSSet otherSet)
    {
        OS.objc_msgSend(this.id_, OS.sel_intersectSet_1, otherSet !is null ? otherSet.id_ : null);
    }

    public void minusSet (NSSet otherSet)
    {
        OS.objc_msgSend(this.id_, OS.sel_minusSet_1, otherSet !is null ? otherSet.id_ : null);
    }

    public void removeAllObjects ()
    {
        OS.objc_msgSend(this.id_, OS.sel_removeAllObjects);
    }

    public void removeObject (id object)
    {
        OS.objc_msgSend(this.id_, OS.sel_removeObject_1, object !is null ? object.id_ : null);
    }

    public void setSet (NSSet otherSet)
    {
        OS.objc_msgSend(this.id_, OS.sel_setSet_1, otherSet !is null ? otherSet.id_ : null);
    }

    public static id setWithCapacity (NSUInteger numItems)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSMutableSet, OS.sel_setWithCapacity_1, numItems);
        return result !is null ? new id(result) : null;
    }

    public void unionSet (NSSet otherSet)
    {
        OS.objc_msgSend(this.id_, OS.sel_unionSet_1, otherSet !is null ? otherSet.id_ : null);
    }

}
