/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSMutableString;

import dwt.internal.cocoa.id;
import dwt.internal.cocoa.NSInteger;
import dwt.internal.cocoa.NSRange;
import dwt.internal.cocoa.NSString;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

public class NSMutableString : NSString
{

    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public void appendFormat (NSString appendFormat)
    {
        OS.objc_msgSend(this.id_, OS.sel_appendFormat_1, appendFormat !is null ? appendFormat.id_ : null);
    }

    public void appendString (NSString aString)
    {
        OS.objc_msgSend(this.id_, OS.sel_appendString_1, aString !is null ? aString.id_ : null);
    }

    public void deleteCharactersInRange (NSRange range)
    {
        OS.objc_msgSend(this.id_, OS.sel_deleteCharactersInRange_1, range);
    }

    public NSMutableString initWithCapacity (NSUInteger capacity)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_initWithCapacity_1, capacity);
        return result !is null ? this : null;
    }

    public void insertString (NSString aString, NSUInteger loc)
    {
        OS.objc_msgSend(this.id_, OS.sel_insertString_1atIndex_1, aString !is null ? aString.id_ : null, loc);
    }

    public void replaceCharactersInRange (NSRange range, NSString aString)
    {
        OS.objc_msgSend(this.id_, OS.sel_replaceCharactersInRange_1withString_1, range, aString !is null ? aString.id_ : null);
    }

    public NSUInteger replaceOccurrencesOfString (NSString target, NSString replacement, NSStringCompareOptions options, NSRange searchRange)
    {
        return cast(NSUInteger) OS.objc_msgSend(this.id_, OS.sel_replaceOccurrencesOfString_1withString_1options_1range_1, target !is null ? target.id_ : null,
                replacement !is null ? replacement.id_ : null, options, searchRange);
    }

    public void setString (NSString aString)
    {
        OS.objc_msgSend(this.id_, OS.sel_setString_1, aString !is null ? aString.id_ : null);
    }

    public static id stringWithCapacity (NSUInteger capacity)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSMutableString, OS.sel_stringWithCapacity_1, capacity);
        return result !is null ? new id(result) : null;
    }

}
