/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSOperation;

import dwt.internal.cocoa.NSArray;
import dwt.internal.cocoa.NSInteger;
import dwt.internal.cocoa.NSObject;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

alias NSInteger NSOperationQueuePriority;

enum
{
    NSOperationQueuePriorityVeryLow = -8,
    NSOperationQueuePriorityLow = -4,
    NSOperationQueuePriorityNormal = 0,
    NSOperationQueuePriorityHigh = 4,
    NSOperationQueuePriorityVeryHigh = 8
}

public class NSOperation : NSObject
{

    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public void addDependency (NSOperation op)
    {
        OS.objc_msgSend(this.id_, OS.sel_addDependency_1, op !is null ? op.id_ : null);
    }

    public void cancel ()
    {
        OS.objc_msgSend(this.id_, OS.sel_cancel);
    }

    public NSArray dependencies ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_dependencies);
        return result !is null ? new NSArray(result) : null;
    }

    public bool isCancelled ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_isCancelled) !is null;
    }

    public bool isConcurrent ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_isConcurrent) !is null;
    }

    public bool isExecuting ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_isExecuting) !is null;
    }

    public bool isFinished ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_isFinished) !is null;
    }

    public bool isReady ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_isReady) !is null;
    }

    public void main ()
    {
        OS.objc_msgSend(this.id_, OS.sel_main);
    }

    public NSOperationQueuePriority queuePriority ()
    {
        return cast(NSOperationQueuePriority) OS.objc_msgSend(this.id_, OS.sel_queuePriority);
    }

    public void removeDependency (NSOperation op)
    {
        OS.objc_msgSend(this.id_, OS.sel_removeDependency_1, op !is null ? op.id_ : null);
    }

    public void setQueuePriority (NSOperationQueuePriority p)
    {
        OS.objc_msgSend(this.id_, OS.sel_setQueuePriority_1, p);
    }

    public void start ()
    {
        OS.objc_msgSend(this.id_, OS.sel_start);
    }

}
