/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSPortCoder;

import dwt.internal.cocoa.id;
import dwt.internal.cocoa.NSArray;
import dwt.internal.cocoa.NSCoder;
import dwt.internal.cocoa.NSConnection;
import dwt.internal.cocoa.NSPort;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

public class NSPortCoder : NSCoder
{

    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public NSConnection connection ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_connection);
        return result !is null ? new NSConnection(result) : null;
    }

    public NSPort decodePortObject ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_decodePortObject);
        return result !is null ? new NSPort(result) : null;
    }

    public void dispatch ()
    {
        OS.objc_msgSend(this.id_, OS.sel_dispatch);
    }

    public void encodePortObject (NSPort aport)
    {
        OS.objc_msgSend(this.id_, OS.sel_encodePortObject_1, aport !is null ? aport.id_ : null);
    }

    public NSPortCoder initWithReceivePort (NSPort rcvPort, NSPort sndPort, NSArray comps)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_initWithReceivePort_1sendPort_1components_1, rcvPort !is null ? rcvPort.id_ : null,
                sndPort !is null ? sndPort.id_ : null, comps !is null ? comps.id_ : null);
        return result !is null ? this : null;
    }

    public bool isBycopy ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_isBycopy) !is null;
    }

    public bool isByref ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_isByref) !is null;
    }

    public static id portCoderWithReceivePort (NSPort rcvPort, NSPort sndPort, NSArray comps)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSPortCoder, OS.sel_portCoderWithReceivePort_1sendPort_1components_1,
                rcvPort !is null ? rcvPort.id_ : null, sndPort !is null ? sndPort.id_ : null, comps !is null ? comps.id_ : null);
        return result !is null ? new id(result) : null;
    }

}
