/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSPrintOperation;

import dwt.internal.cocoa.id;
import dwt.internal.cocoa.NSGraphicsContext;
import dwt.internal.cocoa.NSInteger;
import dwt.internal.cocoa.NSMutableData;
import dwt.internal.cocoa.NSObject;
import dwt.internal.cocoa.NSPrintInfo;
import dwt.internal.cocoa.NSPrintPanel;
import dwt.internal.cocoa.NSRange;
import dwt.internal.cocoa.NSRect;
import dwt.internal.cocoa.NSString;
import dwt.internal.cocoa.NSView;
import dwt.internal.cocoa.NSWindow;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

enum NSPrintingPageOrder
{
    NSDescendingPageOrder = (-1),
    NSSpecialPageOrder = 0,
    NSAscendingPageOrder = 1,
    NSUnknownPageOrder = 2
}

alias NSPrintingPageOrder.NSDescendingPageOrder NSDescendingPageOrder;
alias NSPrintingPageOrder.NSSpecialPageOrder NSSpecialPageOrder;
alias NSPrintingPageOrder.NSAscendingPageOrder NSAscendingPageOrder;
alias NSPrintingPageOrder.NSUnknownPageOrder NSUnknownPageOrder;

public class NSPrintOperation : NSObject
{

    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public static NSPrintOperation static_EPSOperationWithView_insideRect_toData_ (NSView view, NSRect rect, NSMutableData data)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSPrintOperation, OS.sel_EPSOperationWithView_1insideRect_1toData_1,
                view !is null ? view.id_ : null, rect, data !is null ? data.id_ : null);
        return result !is null ? new NSPrintOperation(result) : null;
    }

    public static NSPrintOperation static_EPSOperationWithView_insideRect_toData_printInfo_ (NSView view, NSRect rect, NSMutableData data,
            NSPrintInfo printInfo)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSPrintOperation, OS.sel_EPSOperationWithView_1insideRect_1toData_1printInfo_1,
                view !is null ? view.id_ : null, rect, data !is null ? data.id_ : null, printInfo !is null ? printInfo.id_ : null);
        return result !is null ? new NSPrintOperation(result) : null;
    }

    public static NSPrintOperation static_EPSOperationWithView_insideRect_toPath_printInfo_ (NSView view, NSRect rect, NSString path,
            NSPrintInfo printInfo)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSPrintOperation, OS.sel_EPSOperationWithView_1insideRect_1toPath_1printInfo_1,
                view !is null ? view.id_ : null, rect, path !is null ? path.id_ : null, printInfo !is null ? printInfo.id_ : null);
        return result !is null ? new NSPrintOperation(result) : null;
    }

    public static NSPrintOperation static_PDFOperationWithView_insideRect_toData_ (NSView view, NSRect rect, NSMutableData data)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSPrintOperation, OS.sel_PDFOperationWithView_1insideRect_1toData_1,
                view !is null ? view.id_ : null, rect, data !is null ? data.id_ : null);
        return result !is null ? new NSPrintOperation(result) : null;
    }

    public static NSPrintOperation static_PDFOperationWithView_insideRect_toData_printInfo_ (NSView view, NSRect rect, NSMutableData data,
            NSPrintInfo printInfo)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSPrintOperation, OS.sel_PDFOperationWithView_1insideRect_1toData_1printInfo_1,
                view !is null ? view.id_ : null, rect, data !is null ? data.id_ : null, printInfo !is null ? printInfo.id_ : null);
        return result !is null ? new NSPrintOperation(result) : null;
    }

    public static NSPrintOperation static_PDFOperationWithView_insideRect_toPath_printInfo_ (NSView view, NSRect rect, NSString path,
            NSPrintInfo printInfo)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSPrintOperation, OS.sel_PDFOperationWithView_1insideRect_1toPath_1printInfo_1,
                view !is null ? view.id_ : null, rect, path !is null ? path.id_ : null, printInfo !is null ? printInfo.id_ : null);
        return result !is null ? new NSPrintOperation(result) : null;
    }

    public NSView accessoryView ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_accessoryView);
        return result !is null ? new NSView(result) : null;
    }

    public bool canSpawnSeparateThread ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_canSpawnSeparateThread) !is null;
    }

    public void cleanUpOperation ()
    {
        OS.objc_msgSend(this.id_, OS.sel_cleanUpOperation);
    }

    public NSGraphicsContext context ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_context);
        return result !is null ? new NSGraphicsContext(result) : null;
    }

    public NSGraphicsContext createContext ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_createContext);
        return result !is null ? new NSGraphicsContext(result) : null;
    }

    public static NSPrintOperation currentOperation ()
    {
        objc.id result = OS.objc_msgSend(OS.class_NSPrintOperation, OS.sel_currentOperation);
        return result !is null ? new NSPrintOperation(result) : null;
    }

    public NSInteger currentPage ()
    {
        return cast(NSInteger) OS.objc_msgSend(this.id_, OS.sel_currentPage);
    }

    public bool deliverResult ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_deliverResult) !is null;
    }

    public void destroyContext ()
    {
        OS.objc_msgSend(this.id_, OS.sel_destroyContext);
    }

    public bool isCopyingOperation ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_isCopyingOperation) !is null;
    }

    public NSString jobStyleHint ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_jobStyleHint);
        return result !is null ? new NSString(result) : null;
    }

    public NSString jobTitle ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_jobTitle);
        return result !is null ? new NSString(result) : null;
    }

    public NSPrintingPageOrder pageOrder ()
    {
        return cast(NSPrintingPageOrder) OS.objc_msgSend(this.id_, OS.sel_pageOrder);
    }

    public NSRange pageRange ()
    {
        NSRange result;
        OS.objc_msgSend_stret(&result, this.id_, OS.sel_pageRange);
        return result;
    }

    public NSPrintInfo printInfo ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_printInfo);
        return result !is null ? new NSPrintInfo(result) : null;
    }

    public static NSPrintOperation static_printOperationWithView_ (NSView view)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSPrintOperation, OS.sel_printOperationWithView_1, view !is null ? view.id_ : null);
        return result !is null ? new NSPrintOperation(result) : null;
    }

    public static NSPrintOperation static_printOperationWithView_printInfo_ (NSView view, NSPrintInfo printInfo)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSPrintOperation, OS.sel_printOperationWithView_1printInfo_1, view !is null ? view.id_ : null,
                printInfo !is null ? printInfo.id_ : null);
        return result !is null ? new NSPrintOperation(result) : null;
    }

    public NSPrintPanel printPanel ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_printPanel);
        return result !is null ? new NSPrintPanel(result) : null;
    }

    public bool runOperation ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_runOperation) !is null;
    }

    public void runOperationModalForWindow (NSWindow docWindow, id delegatee, objc.SEL didRunSelector, void* contextInfo)
    {
        OS.objc_msgSend(this.id_, OS.sel_runOperationModalForWindow_1delegate_1didRunSelector_1contextInfo_1,
                docWindow !is null ? docWindow.id_ : null, delegatee !is null ? delegatee.id_ : null, didRunSelector, contextInfo);
    }

    public void setAccessoryView (NSView view)
    {
        OS.objc_msgSend(this.id_, OS.sel_setAccessoryView_1, view !is null ? view.id_ : null);
    }

    public void setCanSpawnSeparateThread (bool canSpawnSeparateThread)
    {
        OS.objc_msgSend(this.id_, OS.sel_setCanSpawnSeparateThread_1, canSpawnSeparateThread);
    }

    public static void setCurrentOperation (NSPrintOperation operation)
    {
        OS.objc_msgSend(OS.class_NSPrintOperation, OS.sel_setCurrentOperation_1, operation !is null ? operation.id_ : null);
    }

    public void setJobStyleHint (NSString hint)
    {
        OS.objc_msgSend(this.id_, OS.sel_setJobStyleHint_1, hint !is null ? hint.id_ : null);
    }

    public void setJobTitle (NSString jobTitle)
    {
        OS.objc_msgSend(this.id_, OS.sel_setJobTitle_1, jobTitle !is null ? jobTitle.id_ : null);
    }

    public void setPageOrder (NSPrintingPageOrder pageOrder)
    {
        OS.objc_msgSend(this.id_, OS.sel_setPageOrder_1, pageOrder);
    }

    public void setPrintInfo (NSPrintInfo printInfo)
    {
        OS.objc_msgSend(this.id_, OS.sel_setPrintInfo_1, printInfo !is null ? printInfo.id_ : null);
    }

    public void setPrintPanel (NSPrintPanel panel)
    {
        OS.objc_msgSend(this.id_, OS.sel_setPrintPanel_1, panel !is null ? panel.id_ : null);
    }

    public void setShowPanels (bool flag)
    {
        OS.objc_msgSend(this.id_, OS.sel_setShowPanels_1, flag);
    }

    public void setShowsPrintPanel (bool flag)
    {
        OS.objc_msgSend(this.id_, OS.sel_setShowsPrintPanel_1, flag);
    }

    public void setShowsProgressPanel (bool flag)
    {
        OS.objc_msgSend(this.id_, OS.sel_setShowsProgressPanel_1, flag);
    }

    public bool showPanels ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_showPanels) !is null;
    }

    public bool showsPrintPanel ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_showsPrintPanel) !is null;
    }

    public bool showsProgressPanel ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_showsProgressPanel) !is null;
    }

    public NSView view ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_view);
        return result !is null ? new NSView(result) : null;
    }

}
