/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSToolbar;

import dwt.internal.cocoa.id;
import dwt.internal.cocoa.NSArray;
import dwt.internal.cocoa.NSDictionary;
import dwt.internal.cocoa.NSInteger;
import dwt.internal.cocoa.NSObject;
import dwt.internal.cocoa.NSString;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

enum NSToolbarDisplayMode
{
    NSToolbarDisplayModeDefault,
    NSToolbarDisplayModeIconAndLabel,
    NSToolbarDisplayModeIconOnly,
    NSToolbarDisplayModeLabelOnly
}

alias NSToolbarDisplayMode.NSToolbarDisplayModeDefault NSToolbarDisplayModeDefault;
alias NSToolbarDisplayMode.NSToolbarDisplayModeIconAndLabel NSToolbarDisplayModeIconAndLabel;
alias NSToolbarDisplayMode.NSToolbarDisplayModeIconOnly NSToolbarDisplayModeIconOnly;
alias NSToolbarDisplayMode.NSToolbarDisplayModeLabelOnly NSToolbarDisplayModeLabelOnly;

enum NSToolbarSizeMode
{
    NSToolbarSizeModeDefault,
    NSToolbarSizeModeRegular,
    NSToolbarSizeModeSmall
}

alias NSToolbarSizeMode.NSToolbarSizeModeDefault NSToolbarSizeModeDefault;
alias NSToolbarSizeMode.NSToolbarSizeModeRegular NSToolbarSizeModeRegular;
alias NSToolbarSizeMode.NSToolbarSizeModeSmall NSToolbarSizeModeSmall;

public class NSToolbar : NSObject
{

    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public bool allowsUserCustomization ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_allowsUserCustomization) !is null;
    }

    public bool autosavesConfiguration ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_autosavesConfiguration) !is null;
    }

    public NSDictionary configurationDictionary ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_configurationDictionary);
        return result !is null ? new NSDictionary(result) : null;
    }

    public bool customizationPaletteIsRunning ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_customizationPaletteIsRunning) !is null;
    }

    public id delegatee ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_delegate);
        return result !is null ? new id(result) : null;
    }

    public NSToolbarDisplayMode displayMode ()
    {
        return cast(NSToolbarDisplayMode) OS.objc_msgSend(this.id_, OS.sel_displayMode);
    }

    public NSString identifier ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_identifier);
        return result !is null ? new NSString(result) : null;
    }

    public id initWithIdentifier (NSString identifier)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_initWithIdentifier_1, identifier !is null ? identifier.id_ : null);
        return result !is null ? new id(result) : null;
    }

    public void insertItemWithItemIdentifier (NSString itemIdentifier, NSInteger index)
    {
        OS.objc_msgSend(this.id_, OS.sel_insertItemWithItemIdentifier_1atIndex_1, itemIdentifier !is null ? itemIdentifier.id_ : null, index);
    }

    public bool isVisible ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_isVisible) !is null;
    }

    public NSArray items ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_items);
        return result !is null ? new NSArray(result) : null;
    }

    public void removeItemAtIndex (NSInteger index)
    {
        OS.objc_msgSend(this.id_, OS.sel_removeItemAtIndex_1, index);
    }

    public void runCustomizationPalette (id sender)
    {
        OS.objc_msgSend(this.id_, OS.sel_runCustomizationPalette_1, sender !is null ? sender.id_ : null);
    }

    public NSString selectedItemIdentifier ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_selectedItemIdentifier);
        return result !is null ? new NSString(result) : null;
    }

    public void setAllowsUserCustomization (bool allowCustomization)
    {
        OS.objc_msgSend(this.id_, OS.sel_setAllowsUserCustomization_1, allowCustomization);
    }

    public void setAutosavesConfiguration (bool flag)
    {
        OS.objc_msgSend(this.id_, OS.sel_setAutosavesConfiguration_1, flag);
    }

    public void setConfigurationFromDictionary (NSDictionary configDict)
    {
        OS.objc_msgSend(this.id_, OS.sel_setConfigurationFromDictionary_1, configDict !is null ? configDict.id_ : null);
    }

    public void setDelegate (id delegatee)
    {
        OS.objc_msgSend(this.id_, OS.sel_setDelegate_1, delegatee !is null ? delegatee.id_ : null);
    }

    public void setDisplayMode (NSToolbarDisplayMode displayMode)
    {
        OS.objc_msgSend(this.id_, OS.sel_setDisplayMode_1, displayMode);
    }

    public void setSelectedItemIdentifier (NSString itemIdentifier)
    {
        OS.objc_msgSend(this.id_, OS.sel_setSelectedItemIdentifier_1, itemIdentifier !is null ? itemIdentifier.id_ : null);
    }

    public void setShowsBaselineSeparator (bool flag)
    {
        OS.objc_msgSend(this.id_, OS.sel_setShowsBaselineSeparator_1, flag);
    }

    public void setSizeMode (NSToolbarSizeMode sizeMode)
    {
        OS.objc_msgSend(this.id_, OS.sel_setSizeMode_1, sizeMode);
    }

    public void setVisible (bool shown)
    {
        OS.objc_msgSend(this.id_, OS.sel_setVisible_1, shown);
    }

    public bool showsBaselineSeparator ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_showsBaselineSeparator) !is null;
    }

    public NSToolbarSizeMode sizeMode ()
    {
        return cast(NSToolbarSizeMode) OS.objc_msgSend(this.id_, OS.sel_sizeMode);
    }

    public void validateVisibleItems ()
    {
        OS.objc_msgSend(this.id_, OS.sel_validateVisibleItems);
    }

    public NSArray visibleItems ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_visibleItems);
        return result !is null ? new NSArray(result) : null;
    }

}
