/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSURLAuthenticationChallenge;

import dwt.internal.cocoa.id;
import dwt.internal.cocoa.NSError;
import dwt.internal.cocoa.NSInteger;
import dwt.internal.cocoa.NSObject;
import dwt.internal.cocoa.NSURLCredential;
import dwt.internal.cocoa.NSURLProtectionSpace;
import dwt.internal.cocoa.NSURLResponse;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

public class NSURLAuthenticationChallenge : NSObject
{

    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public NSError error ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_error);
        return result !is null ? new NSError(result) : null;
    }

    public NSURLResponse failureResponse ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_failureResponse);
        return result !is null ? new NSURLResponse(result) : null;
    }

    public id initWithAuthenticationChallenge (NSURLAuthenticationChallenge challenge, id sender)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_initWithAuthenticationChallenge_1sender_1, challenge !is null ? challenge.id_ : null,
                sender !is null ? sender.id_ : null);
        return result !is null ? new id(result) : null;
    }

    public id initWithProtectionSpace (NSURLProtectionSpace space, NSURLCredential credential, NSInteger previousFailureCount, NSURLResponse response,
            NSError error, id sender)
    {
        objc.id result = OS.objc_msgSend(this.id_,
                OS.sel_initWithProtectionSpace_1proposedCredential_1previousFailureCount_1failureResponse_1error_1sender_1,
                space !is null ? space.id_ : null, credential !is null ? credential.id_ : null, previousFailureCount,
                response !is null ? response.id_ : null, error !is null ? error.id_ : null, sender !is null ? sender.id_ : null);
        return result !is null ? new id(result) : null;
    }

    public NSInteger previousFailureCount ()
    {
        return cast(NSInteger) OS.objc_msgSend(this.id_, OS.sel_previousFailureCount);
    }

    public NSURLCredential proposedCredential ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_proposedCredential);
        return result !is null ? new NSURLCredential(result) : null;
    }

    public NSURLProtectionSpace protectionSpace ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_protectionSpace);
        return result !is null ? new NSURLProtectionSpace(result) : null;
    }

    public id sender ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_sender);
        return result !is null ? new id(result) : null;
    }

}
