/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSURLCache;

import dwt.internal.cocoa.id;
import dwt.internal.cocoa.NSCachedURLResponse;
import dwt.internal.cocoa.NSInteger;
import dwt.internal.cocoa.NSObject;
import dwt.internal.cocoa.NSString;
import dwt.internal.cocoa.NSURLRequest;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

enum NSURLCacheStoragePolicy : NSUInteger
{
    NSURLCacheStorageAllowed,
    NSURLCacheStorageAllowedInMemoryOnly,
    NSURLCacheStorageNotAllowed,
}

alias NSURLCacheStoragePolicy.NSURLCacheStorageAllowed NSURLCacheStorageAllowed;
alias NSURLCacheStoragePolicy.NSURLCacheStorageAllowedInMemoryOnly NSURLCacheStorageAllowedInMemoryOnly;
alias NSURLCacheStoragePolicy.NSURLCacheStorageNotAllowed NSURLCacheStorageNotAllowed;

public class NSURLCache : NSObject
{

    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public NSCachedURLResponse cachedResponseForRequest (NSURLRequest request)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_cachedResponseForRequest_1, request !is null ? request.id_ : null);
        return result !is null ? new NSCachedURLResponse(result) : null;
    }

    public NSUInteger currentDiskUsage ()
    {
        return cast(NSUInteger) OS.objc_msgSend(this.id_, OS.sel_currentDiskUsage);
    }

    public NSUInteger currentMemoryUsage ()
    {
        return cast(NSUInteger) OS.objc_msgSend(this.id_, OS.sel_currentMemoryUsage);
    }

    public NSUInteger diskCapacity ()
    {
        return cast(NSUInteger) OS.objc_msgSend(this.id_, OS.sel_diskCapacity);
    }

    public id initWithMemoryCapacity (NSUInteger memoryCapacity, NSUInteger diskCapacity, NSString path)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_initWithMemoryCapacity_1diskCapacity_1diskPath_1, memoryCapacity, diskCapacity,
                path !is null ? path.id_ : null);
        return result !is null ? new id(result) : null;
    }

    public NSUInteger memoryCapacity ()
    {
        return cast(NSUInteger) OS.objc_msgSend(this.id_, OS.sel_memoryCapacity);
    }

    public void removeAllCachedResponses ()
    {
        OS.objc_msgSend(this.id_, OS.sel_removeAllCachedResponses);
    }

    public void removeCachedResponseForRequest (NSURLRequest request)
    {
        OS.objc_msgSend(this.id_, OS.sel_removeCachedResponseForRequest_1, request !is null ? request.id_ : null);
    }

    public void setDiskCapacity (NSUInteger diskCapacity)
    {
        OS.objc_msgSend(this.id_, OS.sel_setDiskCapacity_1, diskCapacity);
    }

    public void setMemoryCapacity (NSUInteger memoryCapacity)
    {
        OS.objc_msgSend(this.id_, OS.sel_setMemoryCapacity_1, memoryCapacity);
    }

    public static void setSharedURLCache (NSURLCache cache)
    {
        OS.objc_msgSend(OS.class_NSURLCache, OS.sel_setSharedURLCache_1, cache !is null ? cache.id_ : null);
    }

    public static NSURLCache sharedURLCache ()
    {
        objc.id result = OS.objc_msgSend(OS.class_NSURLCache, OS.sel_sharedURLCache);
        return result !is null ? new NSURLCache(result) : null;
    }

    public void storeCachedResponse (NSCachedURLResponse cachedResponse, NSURLRequest request)
    {
        OS.objc_msgSend(this.id_, OS.sel_storeCachedResponse_1forRequest_1, cachedResponse !is null ? cachedResponse.id_ : null,
                request !is null ? request.id_ : null);
    }

}
