/*******************************************************************************
 * Copyright (c) 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     IBM Corporation - initial API and implementation
 *     
 * Port to the D Programming language:
 *     Jacob Carlborg <jacob.carlborg@gmail.com>
 *******************************************************************************/
module dwt.internal.cocoa.NSURLCredential;

import dwt.internal.cocoa.id;
import dwt.internal.cocoa.NSObject;
import dwt.internal.cocoa.NSString;
import dwt.internal.cocoa.OS;
import objc = dwt.internal.objc.runtime;

enum NSURLCredentialPersistence
{
    NSURLCredentialPersistenceNone,
    NSURLCredentialPersistenceForSession,
    NSURLCredentialPersistencePermanent
}

alias NSURLCredentialPersistence.NSURLCredentialPersistenceNone NSURLCredentialPersistenceNone;
alias NSURLCredentialPersistence.NSURLCredentialPersistenceForSession NSURLCredentialPersistenceForSession;
alias NSURLCredentialPersistence.NSURLCredentialPersistencePermanent NSURLCredentialPersistencePermanent;

public class NSURLCredential : NSObject
{

    public this ()
    {
        super();
    }

    public this (objc.id id)
    {
        super(id);
    }

    public static NSURLCredential credentialWithUser (NSString user, NSString password, NSURLCredentialPersistence persistence)
    {
        objc.id result = OS.objc_msgSend(OS.class_NSURLCredential, OS.sel_credentialWithUser_1password_1persistence_1,
                user !is null ? user.id_ : null, password !is null ? password.id_ : null, persistence);
        return result !is null ? new NSURLCredential(result) : null;
    }

    public bool hasPassword ()
    {
        return OS.objc_msgSend(this.id_, OS.sel_hasPassword) !is null;
    }

    public id initWithUser (NSString user, NSString password, NSURLCredentialPersistence persistence)
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_initWithUser_1password_1persistence_1, user !is null ? user.id_ : null,
                password !is null ? password.id_ : null, persistence);
        return result !is null ? new id(result) : null;
    }

    public NSString password ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_password);
        return result !is null ? new NSString(result) : null;
    }

    public NSURLCredentialPersistence persistence ()
    {
        return cast(NSURLCredentialPersistence) OS.objc_msgSend(this.id_, OS.sel_persistence);
    }

    public NSString user ()
    {
        objc.id result = OS.objc_msgSend(this.id_, OS.sel_user);
        return result !is null ? new NSString(result) : null;
    }

}
